@@ -76,6 +76,19 @@ list_multivariate_models <- function() {
   return(list)
 }
 
+#' List multistep models
+#'
+#'
+#' @return list of models
+#' @noRd
+list_multistep_models <- function() {
+  list <- c(
+    "cubist", "glmnet", "mars", "svm-poly", "svm-rbf", "xgboost"
+  )
+
+  return(list)
+}
+
 #' Gets a simple recipe
 #'
 #' @param train_data Training Data
@@ -196,8 +209,8 @@ get_recipe_configurable <- function(train_data,
   center_scale_fn <- function(df) {
     if (center_scale) {
       df %>%
-        recipes::step_center(recipes::all_predictors(), id = "step_center") %>%
-        recipes::step_scale(recipes::all_predictors(), id = "step_scale")
+        recipes::step_center(recipes::all_numeric_predictors(), id = "step_center") %>%
+        recipes::step_scale(recipes::all_numeric_predictors(), id = "step_scale")
     } else {
       df
     }
@@ -560,20 +573,38 @@ arima_boost <- function(train_data,
 #' @param train_data train data
 #' @param model_type single or ensemble model
 #' @param pca pca
+#' @param multistep multistep horizon
+#' @param horizon horizon
+#' @param external_regressors external regressors
+#' @param frequency frequency
 #'
 #' @return Get the cubist model
 #' @noRd
 cubist <- function(train_data,
-                   model_type = "single",
-                   pca) {
-  if (model_type == "ensemble") {
+                   pca,
+                   multistep,
+                   horizon,
+                   external_regressors,
+                   frequency) {
+  if (multistep) {
     recipe_spec_cubist <- train_data %>%
       get_recipe_configurable(
-        rm_date = "with_adj",
+        rm_date = "none",
         step_nzv = "nzv",
         one_hot = FALSE,
         pca = pca
       )
+
+    model_spec_cubist <- cubist_multistep(
+      mode = "regression",
+      committees = tune::tune(),
+      neighbors = tune::tune(),
+      max_rules = tune::tune(),
+      forecast_horizon = horizon,
+      external_regressors = external_regressors,
+      lag_periods = get_lag_periods(NULL, get_date_type(frequency), horizon, TRUE)
+    ) %>%
+      parsnip::set_engine("cubist_multistep_horizon")
   } else {
     recipe_spec_cubist <- train_data %>%
       get_recipe_configurable(
@@ -582,15 +613,15 @@ cubist <- function(train_data,
         one_hot = FALSE,
         pca = pca
       )
-  }
 
-  model_spec_cubist <- parsnip::cubist_rules(
-    mode = "regression",
-    committees = tune::tune(),
-    neighbors = tune::tune(),
-    max_rules = tune::tune()
-  ) %>%
-    parsnip::set_engine("Cubist")
+    model_spec_cubist <- parsnip::cubist_rules(
+      mode = "regression",
+      committees = tune::tune(),
+      neighbors = tune::tune(),
+      max_rules = tune::tune()
+    ) %>%
+      parsnip::set_engine("Cubist")
+  }
 
   wflw_spec_cubist <- get_workflow_simple(
     model_spec_cubist,
@@ -656,23 +687,40 @@ ets <- function(train_data,
 #' GLM Net Function
 #'
 #' @param train_data input data
-#' @param model_type single or ensemble
 #' @param pca pca
+#' @param multistep multistep horizon
+#' @param horizon horizon
+#' @param external_regressors external regressors
+#' @param frequency frequency
 #'
 #' @return Get the GLM Net model
 #' @noRd
 glmnet <- function(train_data,
-                   model_type = "single",
-                   pca) {
-  if (model_type == "ensemble") {
+                   pca,
+                   multistep,
+                   horizon,
+                   external_regressors,
+                   frequency) {
+  # create model recipe and spec
+  if (multistep) {
     recipe_spec_glmnet <- train_data %>%
       get_recipe_configurable(
-        rm_date = "with_adj",
+        rm_date = "none",
         step_nzv = "zv",
         one_hot = FALSE,
         center_scale = TRUE,
         pca = pca
       )
+
+    model_spec_glmnet <- glmnet_multistep(
+      mode = "regression",
+      penalty = tune::tune(),
+      mixture = tune::tune(),
+      forecast_horizon = horizon,
+      external_regressors = external_regressors,
+      lag_periods = get_lag_periods(NULL, get_date_type(frequency), horizon, TRUE)
+    ) %>%
+      parsnip::set_engine("glmnet_multistep_horizon")
   } else {
     recipe_spec_glmnet <- train_data %>%
       get_recipe_configurable(
@@ -682,15 +730,16 @@ glmnet <- function(train_data,
         center_scale = TRUE,
         pca = pca
       )
+
+    model_spec_glmnet <- parsnip::linear_reg(
+      mode = "regression",
+      penalty = tune::tune(),
+      mixture = tune::tune()
+    ) %>%
+      parsnip::set_engine("glmnet")
   }
 
-  model_spec_glmnet <- parsnip::linear_reg(
-    mode = "regression",
-    penalty = tune::tune(),
-    mixture = tune::tune()
-  ) %>%
-    parsnip::set_engine("glmnet")
-
+  # create final model workflow
   wflw_spec_glmnet <- get_workflow_simple(
     model_spec_glmnet,
     recipe_spec_glmnet
@@ -704,25 +753,51 @@ glmnet <- function(train_data,
 #' @param train_data input data
 #' @param model_type single or ensemble
 #' @param pca pca
+#' @param multistep multistep horizon
+#' @param horizon horizon
+#' @param external_regressors external regressors
+#' @param frequency frequency
 #'
 #' @return Get the Mars model spec
 #' @noRd
 mars <- function(train_data,
-                 model_type = "single",
-                 pca) {
-  recipe_spec_mars <- train_data %>%
-    get_recipe_configurable(
-      rm_date = "with_adj",
-      pca = pca
-    )
+                 pca,
+                 multistep,
+                 horizon,
+                 external_regressors,
+                 frequency) {
+  if (multistep) {
+    recipe_spec_mars <- train_data %>%
+      get_recipe_configurable(
+        rm_date = "none",
+        pca = pca
+      )
 
-  model_spec_mars <- parsnip::mars(
-    mode = "regression",
-    num_terms = tune::tune(),
-    prod_degree = tune::tune(),
-    prune_method = tune::tune()
-  ) %>%
-    parsnip::set_engine("earth")
+    model_spec_mars <- mars_multistep(
+      mode = "regression",
+      num_terms = tune::tune(),
+      prod_degree = tune::tune(),
+      prune_method = tune::tune(),
+      forecast_horizon = horizon,
+      external_regressors = external_regressors,
+      lag_periods = get_lag_periods(NULL, get_date_type(frequency), horizon, TRUE)
+    ) %>%
+      parsnip::set_engine("mars_multistep_horizon")
+  } else {
+    recipe_spec_mars <- train_data %>%
+      get_recipe_configurable(
+        rm_date = "with_adj",
+        pca = pca
+      )
+
+    model_spec_mars <- parsnip::mars(
+      mode = "regression",
+      num_terms = tune::tune(),
+      prod_degree = tune::tune(),
+      prune_method = tune::tune()
+    ) %>%
+      parsnip::set_engine("earth")
+  }
 
   wflw_spec_mars <- get_workflow_simple(
     model_spec_mars,
@@ -1024,12 +1099,20 @@ stlm_ets <- function(train_data,
 #' @param train_data input data
 #' @param model_type single or ensemble
 #' @param pca pca
+#' @param multistep multistep horizon
+#' @param horizon forecast horizon
+#' @param external_regressors external regressors
+#' @param frequency frequency
 #'
 #' @return Get SVM Poly model
 #' @noRd
 svm_poly <- function(train_data,
                      model_type = "single",
-                     pca) {
+                     pca,
+                     multistep,
+                     horizon,
+                     external_regressors,
+                     frequency) {
   if (model_type == "ensemble") {
     recipe_spec_svm <- train_data %>%
       get_recipe_configurable(
@@ -1037,6 +1120,35 @@ svm_poly <- function(train_data,
         one_hot = FALSE,
         pca = pca
       )
+
+    model_spec_svm <- parsnip::svm_poly(
+      mode = "regression",
+      cost = tune::tune(),
+      degree = tune::tune(),
+      margin = tune::tune(),
+      scale_factor = tune::tune()
+    ) %>%
+      parsnip::set_engine("kernlab")
+  } else if (multistep) {
+    recipe_spec_svm <- train_data %>%
+      get_recipe_configurable(
+        rm_date = "none",
+        norm_date_adj_year = TRUE,
+        one_hot = FALSE,
+        pca = pca
+      )
+
+    model_spec_svm <- svm_poly_multistep(
+      mode = "regression",
+      cost = tune::tune(),
+      degree = tune::tune(),
+      margin = tune::tune(),
+      scale_factor = tune::tune(),
+      lag_periods = get_lag_periods(NULL, get_date_type(frequency), horizon, TRUE),
+      external_regressors = external_regressors,
+      forecast_horizon = horizon
+    ) %>%
+      parsnip::set_engine("svm_poly_multistep_horizon")
   } else {
     recipe_spec_svm <- train_data %>%
       get_recipe_configurable(
@@ -1045,16 +1157,16 @@ svm_poly <- function(train_data,
         one_hot = FALSE,
         pca = pca
       )
-  }
 
-  model_spec_svm <- parsnip::svm_poly(
-    mode = "regression",
-    cost = tune::tune(),
-    degree = tune::tune(),
-    margin = tune::tune(),
-    scale_factor = tune::tune()
-  ) %>%
-    parsnip::set_engine("kernlab")
+    model_spec_svm <- parsnip::svm_poly(
+      mode = "regression",
+      cost = tune::tune(),
+      degree = tune::tune(),
+      margin = tune::tune(),
+      scale_factor = tune::tune()
+    ) %>%
+      parsnip::set_engine("kernlab")
+  }
 
   wflw_spec_tune_svm <- get_workflow_simple(
     model_spec_svm,
@@ -1069,12 +1181,20 @@ svm_poly <- function(train_data,
 #' @param train_data input data
 #' @param model_type single or ensemble
 #' @param pca pca
+#' @param multistep multistep horizon
+#' @param horizon forecast horizon
+#' @param external_regressors external regressors
+#' @param frequency frequency
 #'
 #' @return Get SVM RBF model
 #' @noRd
 svm_rbf <- function(train_data,
                     model_type = "single",
-                    pca) {
+                    pca,
+                    multistep,
+                    horizon,
+                    external_regressors,
+                    frequency) {
   if (model_type == "ensemble") {
     recipe_spec_svm <- train_data %>%
       get_recipe_configurable(
@@ -1082,6 +1202,33 @@ svm_rbf <- function(train_data,
         one_hot = FALSE,
         pca = pca
       )
+
+    model_spec_svm <- parsnip::svm_rbf(
+      mode = "regression",
+      cost = tune::tune(),
+      rbf_sigma = tune::tune(),
+      margin = tune::tune()
+    ) %>%
+      parsnip::set_engine("kernlab")
+  } else if (multistep) {
+    recipe_spec_svm <- train_data %>%
+      get_recipe_configurable(
+        norm_date_adj_year = TRUE,
+        rm_date = "none",
+        one_hot = FALSE,
+        pca = pca
+      )
+
+    model_spec_svm <- svm_rbf_multistep(
+      mode = "regression",
+      cost = tune::tune(),
+      rbf_sigma = tune::tune(),
+      margin = tune::tune(),
+      lag_periods = get_lag_periods(NULL, get_date_type(frequency), horizon, TRUE),
+      external_regressors = external_regressors,
+      forecast_horizon = horizon
+    ) %>%
+      parsnip::set_engine("svm_rbf_multistep_horizon")
   } else {
     recipe_spec_svm <- train_data %>%
       get_recipe_configurable(
@@ -1090,15 +1237,16 @@ svm_rbf <- function(train_data,
         one_hot = FALSE,
         pca = pca
       )
+
+    model_spec_svm <- parsnip::svm_rbf(
+      mode = "regression",
+      cost = tune::tune(),
+      rbf_sigma = tune::tune(),
+      margin = tune::tune()
+    ) %>%
+      parsnip::set_engine("kernlab")
   }
 
-  model_spec_svm <- parsnip::svm_rbf(
-    mode = "regression",
-    cost = tune::tune(),
-    rbf_sigma = tune::tune(),
-    margin = tune::tune()
-  ) %>%
-    parsnip::set_engine("kernlab")
 
   wflw_spec_tune_svm <- get_workflow_simple(
     model_spec_svm,
@@ -1165,24 +1313,44 @@ theta <- function(train_data,
 #' XGBoost
 #'
 #' @param train_data input table
-#' @param model_type single or ensemble
 #' @param pca pca
+#' @param multistep multistep horizon
+#' @param horizon forecast horizon
+#' @param external_regressors external regressors
+#' @param frequency
 #'
 #' @return Get XGBoost model
 #' @noRd
 xgboost <- function(train_data,
-                    model_type = "single",
-                    pca) {
-
-  # create model recipe
-  if (model_type == "ensemble") {
+                    pca,
+                    multistep,
+                    horizon,
+                    external_regressors,
+                    frequency) {
+  # create model recipe and spec
+  if (multistep) {
     recipe_spec_xgboost <- train_data %>%
       get_recipe_configurable(
-        rm_date = "with_adj",
+        rm_date = "none",
         step_nzv = "zv",
         one_hot = TRUE,
         pca = pca
       )
+
+    model_spec_xgboost <- xgboost_multistep(
+      lag_periods = get_lag_periods(NULL, get_date_type(frequency), horizon, TRUE),
+      external_regressors = external_regressors,
+      forecast_horizon = horizon,
+      mode = "regression",
+      trees = tune::tune(),
+      tree_depth = tune::tune(),
+      learn_rate = tune::tune(),
+      min_n = tune::tune(),
+      sample_size = tune::tune(),
+      mtry = tune::tune(),
+      loss_reduction = tune::tune()
+    ) %>%
+      parsnip::set_engine("xgboost_multistep_horizon")
   } else {
     recipe_spec_xgboost <- train_data %>%
       get_recipe_configurable(
@@ -1191,17 +1359,18 @@ xgboost <- function(train_data,
         one_hot = TRUE,
         pca = pca
       )
+
+    model_spec_xgboost <- parsnip::boost_tree(
+      mode = "regression",
+      trees = tune::tune(),
+      tree_depth = tune::tune(),
+      learn_rate = tune::tune(),
+      loss_reduction = tune::tune()
+    ) %>%
+      parsnip::set_engine("xgboost")
   }
 
-  model_spec_xgboost <- parsnip::boost_tree(
-    mode = "regression",
-    trees = tune::tune(),
-    tree_depth = tune::tune(),
-    learn_rate = tune::tune(),
-    loss_reduction = tune::tune()
-  ) %>%
-    parsnip::set_engine("xgboost")
-
+  # create model workflow
   wflw_spec_tune_xgboost <- get_workflow_simple(
     model_spec_xgboost,
     recipe_spec_xgboost
